ComposePipeline

Struct ComposePipeline 

pub struct ComposePipeline<T> {
    pub anchor: Box<dyn Anchor>,
    pub objective: Box<dyn Objective<T>>,
    pub selector: Box<dyn Selector<T>>,
}
Pipeline that scores candidates with an objective then packs to budget via a selector.

Fields

anchor: Box<dyn Anchor>objective: Box<dyn Objective<T>>selector: Box<dyn Selector<T>>

Implementations

Source

impl<T: Clone + Send + Sync + 'static> ComposePipeline<T>

pub fn execute( &self, _graph: &AnchorGraph, candidates: Vec<SelectorInput<T>>, budget: usize, weights: &SelectorWeights, context: &ObjectiveContext, ) -> Result<SelectorOutput<T>, FoldError>

Score candidates with the objective, then pack under budget with the selector.