pub struct FoldOutcome<S> {
pub state: S,
pub entries_processed: usize,
pub started_at: DateTime<Utc>,
pub completed_at: DateTime<Utc>,
pub context: FoldContext,
pub metadata: Value,
}Expand description
Outcome of a fold operation.
Contains the derived state along with metadata about the fold execution.
Fields
state: SThe derived state
entries_processed: usizeNumber of entries processed
started_at: DateTime<Utc>When the fold started
completed_at: DateTime<Utc>When the fold completed
context: FoldContextContext used for the fold
metadata: ValueOptional metadata
Implementations
Sourceimpl<S> FoldOutcome<S>
impl<S> FoldOutcome<S>
Sourcepub fn new(state: S, entries_processed: usize, context: FoldContext) -> Self
pub fn new(state: S, entries_processed: usize, context: FoldContext) -> Self
Create a new fold result with identical start and completion timestamps.
Sourcepub fn with_timing(
state: S,
entries_processed: usize,
context: FoldContext,
started_at: DateTime<Utc>,
) -> Self
pub fn with_timing( state: S, entries_processed: usize, context: FoldContext, started_at: DateTime<Utc>, ) -> Self
Create with timing information.
Sourcepub fn with_elapsed(
state: S,
entries_processed: usize,
context: FoldContext,
started_at: DateTime<Utc>,
elapsed: Duration,
) -> Self
pub fn with_elapsed( state: S, entries_processed: usize, context: FoldContext, started_at: DateTime<Utc>, elapsed: Duration, ) -> Self
Create with timing information derived from a monotonic elapsed duration.
Avoids a second Utc::now() call by computing completed_at from
started_at + elapsed.
Sourcepub fn with_metadata(self, metadata: Value) -> Self
pub fn with_metadata(self, metadata: Value) -> Self
Set metadata.
Sourcepub fn map<T, F: FnOnce(S) -> T>(self, f: F) -> FoldOutcome<T>
pub fn map<T, F: FnOnce(S) -> T>(self, f: F) -> FoldOutcome<T>
Map the state to a different type.